summaryrefslogtreecommitdiffstats
path: root/libavcodec/ass.h
diff options
context:
space:
mode:
authorClément Bœsch <ubitux@gmail.com>2012-05-26 22:36:31 +0200
committerClément Bœsch <ubitux@gmail.com>2012-05-29 21:33:28 +0200
commitd51e08bb89f7a93f471bc14ad00c14ac986cfcf0 (patch)
tree8675f875aad6e370b73ef62e0abcb02bd5d989d9 /libavcodec/ass.h
parente7cb161515fc9fb6d30d1681d64d9ba7ad737a4e (diff)
downloadffmpeg-streaming-d51e08bb89f7a93f471bc14ad00c14ac986cfcf0.zip
ffmpeg-streaming-d51e08bb89f7a93f471bc14ad00c14ac986cfcf0.tar.gz
lavc: switch from ts_end to duration in ff_ass_add_rect.
Make possible a end-to-presentation duration.
Diffstat (limited to 'libavcodec/ass.h')
-rw-r--r--libavcodec/ass.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/libavcodec/ass.h b/libavcodec/ass.h
index efff44d..4606563 100644
--- a/libavcodec/ass.h
+++ b/libavcodec/ass.h
@@ -74,7 +74,8 @@ int ff_ass_subtitle_header_default(AVCodecContext *avctx);
* @param sub pointer to the AVSubtitle
* @param dialog ASS dialog to add to sub
* @param ts_start start timestamp for this dialog (in 1/100 second unit)
* @param ts_end end timestamp for this dialog (in 1/100 second unit)
* @param raw when set to 1, it indicates that dialog contains a whole ASS
* dialog line which should be copied as is.
* when set to 0, it indicates that dialog contains only the Text
@@ -85,6 +86,6 @@ int ff_ass_subtitle_header_default(AVCodecContext *avctx);
* A negative value indicates an error.
*/
int ff_ass_add_rect(AVSubtitle *sub, const char *dialog,
- int ts_start, int ts_end, int raw);
+ int ts_start, int duration, int raw);
#endif /* AVCODEC_ASS_H */
OpenPOWER on IntegriCloud
@@ -74,7 +74,8 @@ int ff_ass_subtitle_header_default(AVCodecContext *avctx);
* @param dialog ASS dialog to add to sub
* @param ts_start start timestamp for this dialog (in 1/100 second unit)
- * @param ts_end end timestamp for this dialog (in 1/100 second unit)
+ * @param duration duration for this dialog (in 1/100 second unit), can be -1
+ * to last until the end of the presentation
* @param raw when set to 1, it indicates that dialog contains a whole ASS
* dialog line which should be copied as is.